package com.persagy.dmp.admin.controller;

import com.persagy.common.criteria.JacksonCriteria;
import com.persagy.common.web.MapResponse;
import com.persagy.common.web.PagedResponse;
import com.persagy.dmp.admin.entity.TransObjectInfo;
import com.persagy.dmp.admin.model.DownloadModel;
import com.persagy.dmp.admin.service.TransObjectInfoService;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.OutputStream;
import java.net.URLEncoder;

/**
 * @author: yaoll
 * @date: 2021-01-04
 * @verison: 1.0
 */
@Slf4j
@RestController
@RequestMapping("/admin/dmp/rwd/trans/object/info")
public class TransObjectInfoController {

    @Autowired
    private TransObjectInfoService service;

    @PostMapping("/query")
    public PagedResponse<TransObjectInfo> query(@RequestBody JacksonCriteria criteria) {
        return service.query(criteria);
    }

    @PostMapping("/deleteByProjectId")
    public MapResponse deleteByProjectId(@RequestParam String projectId) {
        return service.deleteByProjectId(projectId);
    }

    @PostMapping("/download")
    public void download(@RequestParam String projectId, HttpServletResponse response) {
        DownloadModel result = service.download(projectId);
        String fileName = result.getName();
        downloadWorkbook(response, fileName, result.getWorkbook());
    }

    @PostMapping("/upload")
    public MapResponse upload(@RequestParam("groupCode") String groupCode,
                              @RequestParam("projectId") String projectId,
                              @RequestParam("file") MultipartFile file) {
        return service.upload(groupCode, projectId, file);
    }

    private void downloadWorkbook(HttpServletResponse resp, String fileName, Workbook workbook) {
        OutputStream out = null;
        try {
            resp.reset();// 清空输出流
            String resultFileName = URLEncoder.encode(fileName, "UTF-8");
            resp.setCharacterEncoding("UTF-8");
            resp.setHeader("Content-disposition", "attachment; filename=" + resultFileName);// 设定输出文件头
            resp.setContentType("application/msexcel");// 定义输出类型
            out = resp.getOutputStream();
            workbook.write(out);
            out.flush();
            log.info("download over: {}", fileName);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                if (out != null) {
                    out.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

}
